
# Slot: description


text of an attributed description

URI: [meta:alt_description_text](https://w3id.org/biolink/biolinkml/meta/alt_description_text)

## Domain and Range

[AltDescription](AltDescription.md) ->  <sub>REQ</sub> [String](String.md)

## Parents


## Children


## Used by

 * [AltDescription](AltDescription.md)
